@@ -2,7 +2,7 @@ import torch
 import numpy as np
 from kevin_toolbox.env_info import version
 
-if version.compare(torch.__version__, "<", "1.2"):
+if version.compare(torch.__version__, "<", "1.2", mode="short"):
     """
         参考 torch.where()
             在 1.1 版本及其之前的 pytorch 中的 torch.where()，
@@ -15,7 +15,7 @@ if version.compare(torch.__version__, "<", "1.2"):
     def where(*args):
         if len(args) == 1:
             res = np.where(args[0].cpu())
-            return torch.as_tensor(res, device=args[0].device)
+            return tuple(torch.as_tensor(i, device=args[0].device) for i in res)
         else:
             return torch.where(*args)
 else:
